==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AStaticModifier.h <==
// public final class soot.jimple.parser.node.AStaticModifier

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c86ad6674630c664 soot_jimple_parser_node_AStaticModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_AStaticModifier_H_
#define _JC_soot_jimple_parser_node_AStaticModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TStatic$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AStaticModifier$sub_refs	_jc_soot_jimple_parser_node_AStaticModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AStaticModifier$sub_nonrefs	_jc_soot_jimple_parser_node_AStaticModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AStaticModifier$refs	_jc_soot_jimple_parser_node_AStaticModifier$refs;
typedef struct _jc_soot_jimple_parser_node_AStaticModifier$nonrefs	_jc_soot_jimple_parser_node_AStaticModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AStaticModifier$object	_jc_soot_jimple_parser_node_AStaticModifier$object;

typedef const struct _jc_soot_jimple_parser_node_AStaticModifier$vmethods	_jc_soot_jimple_parser_node_AStaticModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AStaticModifier$vtable	_jc_soot_jimple_parser_node_AStaticModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_AStaticModifier$vtype	_jc_soot_jimple_parser_node_AStaticModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AStaticModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *);
extern void _jc_soot_jimple_parser_node_AStaticModifier$method$_init$8c711a7be34e82d7(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_soot_jimple_parser_node_TStatic$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AStaticModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AStaticModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *);
extern struct _jc_soot_jimple_parser_node_TStatic$object *_jc_soot_jimple_parser_node_AStaticModifier$method$getStatic$e99f1d5a3832b36d(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *);
extern void _jc_soot_jimple_parser_node_AStaticModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AStaticModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AStaticModifier$method$setStatic$8921314d5c9e61b7(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_soot_jimple_parser_node_TStatic$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AStaticModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AStaticModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AStaticModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AStaticModifier$method_info$getStatic$e99f1d5a3832b36d;
extern _jc_method _jc_soot_jimple_parser_node_AStaticModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AStaticModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AStaticModifier$method_info$setStatic$8921314d5c9e61b7;
extern _jc_method _jc_soot_jimple_parser_node_AStaticModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AStaticModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *);
	struct _jc_soot_jimple_parser_node_TStatic$object	*(*getStatic$e99f1d5a3832b36d)(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setStatic$8921314d5c9e61b7)(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_soot_jimple_parser_node_TStatic$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AStaticModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_AStaticModifier$vmethods	soot_jimple_parser_node_AStaticModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_AStaticModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AStaticModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AStaticModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TStatic$object	*__5fstatic__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AStaticModifier$refs {
    _jc_soot_jimple_parser_node_AStaticModifier$sub_refs	soot_jimple_parser_node_AStaticModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AStaticModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AStaticModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_AStaticModifier$sub_nonrefs	soot_jimple_parser_node_AStaticModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AStaticModifier$object {
	_jc_soot_jimple_parser_node_AStaticModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AStaticModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_AStaticModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AStaticModifier$vtype _jc_soot_jimple_parser_node_AStaticModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AStaticModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AStaticModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_AStaticModifier_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AStaticModifier.h <==
// public final class soot.jimple.parser.node.AStaticModifier

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c86ad6674630c664 soot_jimple_parser_node_AStaticModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_AStaticModifier_H_
#define _JC_soot_jimple_parser_node_AStaticModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TStatic$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AStaticModifier$sub_refs	_jc_soot_jimple_parser_node_AStaticModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AStaticModifier$sub_nonrefs	_jc_soot_jimple_parser_node_AStaticModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AStaticModifier$refs	_jc_soot_jimple_parser_node_AStaticModifier$refs;
typedef struct _jc_soot_jimple_parser_node_AStaticModifier$nonrefs	_jc_soot_jimple_parser_node_AStaticModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AStaticModifier$object	_jc_soot_jimple_parser_node_AStaticModifier$object;

typedef const struct _jc_soot_jimple_parser_node_AStaticModifier$vmethods	_jc_soot_jimple_parser_node_AStaticModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AStaticModifier$vtable	_jc_soot_jimple_parser_node_AStaticModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_AStaticModifier$vtype	_jc_soot_jimple_parser_node_AStaticModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AStaticModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AStaticModifier$method$_init$8c711a7be34e82d7(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_soot_jimple_parser_node_TStatic$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AStaticModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AStaticModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TStatic$object *_jc_soot_jimple_parser_node_AStaticModifier$method$getStatic$e99f1d5a3832b36d(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AStaticModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AStaticModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AStaticModifier$method$setStatic$8921314d5c9e61b7(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_soot_jimple_parser_node_TStatic$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AStaticModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AStaticModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AStaticModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AStaticModifier$method_info$getStatic$e99f1d5a3832b36d;
extern _jc_method _jc_soot_jimple_parser_node_AStaticModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AStaticModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AStaticModifier$method_info$setStatic$8921314d5c9e61b7;
extern _jc_method _jc_soot_jimple_parser_node_AStaticModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AStaticModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TStatic$object	*(*getStatic$e99f1d5a3832b36d)(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setStatic$8921314d5c9e61b7)(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *, struct _jc_soot_jimple_parser_node_TStatic$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AStaticModifier$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AStaticModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_AStaticModifier$vmethods	soot_jimple_parser_node_AStaticModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_AStaticModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AStaticModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AStaticModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TStatic$object	*__5fstatic__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AStaticModifier$refs {
    _jc_soot_jimple_parser_node_AStaticModifier$sub_refs	soot_jimple_parser_node_AStaticModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AStaticModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AStaticModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_AStaticModifier$sub_nonrefs	soot_jimple_parser_node_AStaticModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AStaticModifier$object {
	_jc_soot_jimple_parser_node_AStaticModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AStaticModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_AStaticModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AStaticModifier$vtype _jc_soot_jimple_parser_node_AStaticModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AStaticModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AStaticModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_AStaticModifier_H_ */
